# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext as _

from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.models import DateModel, UserModel, OrderedModel

from jmb.showcase.models import Category


###################################
#           CMS MODELS            #
###################################
class ItemSettings(CMSPlugin):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
        blank=True, null=True,
    )
    slugs_included = models.CharField(
        _("Slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including item slug(s), separated by ','")
    )
    tales_included = models.CharField(
        _("Tales included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including item tale(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        max_length=150,
        blank=True,
        help_text=_("(optional) Excluding item slug(s), separated by ','")
    )
    tales_excluded = models.CharField(
        max_length=150,
        blank=True,
        help_text=_("(optional) Excluding item tale(s), separated by ','")
    )
    ordering = models.CharField(
        _("Items order"),
        max_length=100,
        default='ordering, title, publication_date',
        help_text=_("Items ordering fields")
    )
    objects_per_page = models.IntegerField(
        default=10,
    )
    adjacent_pages = models.IntegerField(
        default=2,
    )
    show_pagination = models.BooleanField(
        default=True,
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.SHOWCASE_CMSPLUGIN_ALL_TEMPLATES,
        default="cms_plugins/showcase_item_list.html",
        #        editable=len(settings.SHOWCASE_CMSPLUGIN_TEMPLATES) > 1
    )

    def __unicode__(self):
        if self.name:
            return self.name
        return self.template_name

    class Meta:
        app_label = "showcase"

    def copy_relations(self, oldinstance):
        for item_category in oldinstance.categories.all():
            ItemCategory(
                item_setting=self,
                category=item_category.category,
            ).save()


class ItemCategory(DateModel, UserModel, OrderedModel):
    item_setting = models.ForeignKey(
        ItemSettings,
        verbose_name=_("Item setting"),
        related_name='categories',
    )
    category = models.ForeignKey(
        Category,
        verbose_name=_('Category'),
        related_name='cmsplugin_categories',
    )

    class Meta:
        app_label = "showcase"
        verbose_name = _("Item categories")
        verbose_name_plural = _("Items categories")
        ordering = ('item_setting', 'ordering')

    def __unicode__(self):
        return u"{} {}".format(self.item_setting, self.category)


class ShowcaseFilterSettings(CMSPlugin):
    item_plugin_setting = models.OneToOneField(
        ItemSettings,
        related_name="ordering_plugin_settings"
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.SHOWCASE_FILTER_CMSPLUGIN_TEMPLATES,
        default="bootstrap3/showcase/cms_plugins/showcase_filter.html",
    )

    def __unicode__(self):
        return u"{0}".format(self.item_plugin_setting)

    class Meta:
        app_label = "showcase"


class ShowcaseSelectFilterSettings(CMSPlugin):
    item_plugin_setting = models.OneToOneField(
        ItemSettings,
        related_name="category_select_filter_settings"
    )
    template_name = models.CharField(
        _("Template"),
        max_length=150,
        choices=settings.SHOWCASE_CATEGORY_SELECT_FILTER_CMSPLUGIN_TEMPLATES,
        default="bootstrap3/showcase/cms_plugins/showcase_category_select_filter.html",
    )

    def __unicode__(self):
        return u"{0}".format(self.template_name)

    class Meta:
        app_label = "showcase"
