# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
from django.conf import settings
import image_cropping.fields
import jmb.core.db.fields


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('cms', '0012_auto_20150607_2207'),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('slug', models.SlugField(unique=True, verbose_name='Slug')),
                ('creator', models.ForeignKey(related_name='showcase_category_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='showcase_category_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['ordering', 'title'],
                'verbose_name': 'category',
                'verbose_name_plural': 'categories',
            },
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('tale', models.CharField(default=b'now', max_length=100, null=True, help_text='in future we may have more tales for showing dynamic content', blank=True)),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('slug', models.SlugField(verbose_name='Slug')),
                ('content', jmb.core.db.fields.HTMLFieldTinyMCE(help_text='Full description', null=True, verbose_name='Content', blank=True)),
                ('image', models.ImageField(help_text="if 'show_image' is checked, this one will be showed", upload_to=b'showcase/img/', null=True, verbose_name='Image', blank=True)),
                (b'small_image', image_cropping.fields.ImageRatioField(b'image', settings.SHOWCASE_ITEM_SMALL_IMAGE_CROPPING, hide_image_field=False, size_warning=True, allow_fullsize=False, free_crop=False, adapt_rotation=False, help_text=None, verbose_name='small image')),
                ('link', models.URLField(help_text='if link_type is external content, this link will be opened', null=True, verbose_name='Link', blank=True)),
                ('file', models.FileField(help_text='if link_type is downloadable content, this item will be downloaded', upload_to=b'showcase/file/', null=True, verbose_name='File', blank=True)),
                ('publication_date', models.DateField(default=django.utils.timezone.now, verbose_name='Publication date')),
                ('show_image', models.BooleanField(default=True, verbose_name='Show image')),
                ('show_link', models.BooleanField(default=True, verbose_name='Show link')),
                ('link_type', models.CharField(default=b'int', max_length=3, verbose_name='Link type', choices=[(b'int', b'contenuto interno'), (b'ext', b'contenuto esterno'), (b'dld', b'contenuto scaricabile')])),
                ('categories', models.ManyToManyField(related_name='items', verbose_name='categories', to='showcase.Category', db_index=True)),
                ('creator', models.ForeignKey(related_name='showcase_item_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='showcase_item_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['title', '-publication_date'],
                'verbose_name': 'item',
                'verbose_name_plural': 'items',
            },
        ),
        migrations.CreateModel(
            name='ItemCategory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('category', models.ForeignKey(related_name='cmsplugin_categories', verbose_name='Categoria', to='showcase.Category')),
                ('creator', models.ForeignKey(related_name='showcase_itemcategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('item_setting', 'ordering'),
                'verbose_name': 'Item categories',
                'verbose_name_plural': 'Items categories',
            },
        ),
        migrations.CreateModel(
            name='ItemSettings',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('name', models.CharField(max_length=255, null=True, verbose_name='nome', blank=True)),
                ('slugs_included', models.CharField(help_text="(Optional) Including item slug(s), separated by ','", max_length=150, verbose_name='Slugs included', blank=True)),
                ('tales_included', models.CharField(help_text="(Optional) Including item tale(s), separated by ','", max_length=150, verbose_name='Tales included', blank=True)),
                ('slugs_excluded', models.CharField(help_text="(optional) Excluding item slug(s), separated by ','", max_length=150, blank=True)),
                ('tales_excluded', models.CharField(help_text="(optional) Excluding item tale(s), separated by ','", max_length=150, blank=True)),
                ('ordering', models.CharField(default=b'ordering, title, publication_date', help_text='Items ordering fields', max_length=100, verbose_name='Items order')),
                ('objects_per_page', models.IntegerField(default=10)),
                ('adjacent_pages', models.IntegerField(default=2)),
                ('template_name', models.CharField(default=b'cms_plugins/showcase_item_list.html', max_length=150, verbose_name='Template', choices=[(b'showcase/cms_plugins/showcase_item_list.html', 'Showcase item list'), (b'bootstrap3/showcase/cms_plugins/showcase_item_by_category_list.html', 'B3 - Showcase by category list'), (b'bootstrap3/showcase/cms_plugins/showcase_item_by_category_thumb_list.html', 'B3 - Showcase by category thumb list')])),
            ],
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='ShowcaseFilterSettings',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('template_name', models.CharField(default=b'bootstrap3/showcase/cms_plugins/showcase_filter.html', max_length=150, verbose_name='Template', choices=[(b'bootstrap3/showcase/cms_plugins/showcase_filter.html', 'B3 - Showcase filter')])),
                ('item_plugin_setting', models.OneToOneField(related_name='ordering_plugin_settings', to='showcase.ItemSettings')),
            ],
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='ShowcaseSelectFilterSettings',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('template_name', models.CharField(default=b'bootstrap3/showcase/cms_plugins/showcase_category_select_filter.html', max_length=150, verbose_name='Template', choices=[(b'bootstrap3/showcase/cms_plugins/showcase_category_select_filter.html', 'B3 - News category select filter')])),
                ('item_plugin_setting', models.OneToOneField(related_name='category_select_filter_settings', to='showcase.ItemSettings')),
            ],
            bases=('cms.cmsplugin',),
        ),
        migrations.AddField(
            model_name='itemcategory',
            name='item_setting',
            field=models.ForeignKey(related_name='categories', verbose_name='Item setting', to='showcase.ItemSettings'),
        ),
        migrations.AddField(
            model_name='itemcategory',
            name='last_modifier',
            field=models.ForeignKey(related_name='showcase_itemcategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
    ]
